@@ -14,18 +14,19 @@ def pre_save_listener(instance, **kwargs):
     setattr(instance, field_obj.doy_name, birthday.timetuple().tm_yday)
 
 
-class BirthdayField(DateField):        
-
+class BirthdayField(DateField):
     def contribute_to_class(self, cls, name):
-        super(BirthdayField, self).contribute_to_class(cls, name)
-
-        if hasattr(cls._meta, 'birthday_field'):
-            raise FieldError(
-                "django-birthday does not support multiple BirthdayFields on a single model")
+        if hasattr(cls._meta, "birthday_field"):
+            raise FieldError("django-birthday does not support multiple BirthdayFields on a single model")
         cls._meta.birthday_field = self
 
-        self.doy_name = '%s_dayofyear_internal' % name
+        self.doy_name = "%s_dayofyear_internal" % name
         if not hasattr(cls, self.doy_name):
-            PositiveSmallIntegerField(editable=False, default=None, null=True).contribute_to_class(cls, self.doy_name)
+            dayofyear_field = PositiveSmallIntegerField(editable=False, default=None, null=True)
+            dayofyear_field.creation_counter = self.creation_counter
+
+            cls.add_to_class(self.doy_name, dayofyear_field)
+
+        super(BirthdayField, self).contribute_to_class(cls, name)
 
         pre_save.connect(pre_save_listener, sender=cls)
